@@ -3,12 +3,7 @@ from django.contrib.auth import get_user_model
 from notify.models import Notification
 from notify.signals import notify
 from django.utils import timezone
-
-try:
-    from django.core.urlresolvers import reverse
-except ImportError:
-    from django.urls import reverse
-
+from django.core.urlresolvers import reverse
 import json
 from django.template import Template, Context, RequestContext
 from django.test.client import RequestFactory
@@ -256,7 +251,7 @@ class NotificationViewTest(TestCase):
         # Marking as read
         ctx = {'action': 'read', 'id': first_nf_id, 'next': '/notifications/'}
         response = self.client.post(reverse('notifications:mark'), ctx)
-        self.assertRedirects(response, '/notifications/',
+        self.assertRedirects(response, 'http://testserver/notifications/',
                              target_status_code=404, status_code=302)
 
         nf = Notification.objects.get(pk=first_nf_id)
@@ -269,7 +264,7 @@ class NotificationViewTest(TestCase):
         ctx2 = {'action': 'unread', 'id': first_nf_id,
                 'next': '/notifications/'}
         response_2 = self.client.post(reverse('notifications:mark'), ctx2)
-        self.assertRedirects(response_2, '/notifications/',
+        self.assertRedirects(response_2, 'http://testserver/notifications/',
                              target_status_code=404, status_code=302)
         nf_2 = Notification.objects.get(pk=first_nf_id)
         self.assertFalse(nf_2.read)
@@ -482,7 +477,7 @@ class NotificationViewTest(TestCase):
 
         for json_nf in resp['notifications']:
             self.assertIn(json_nf['id'],
-                          [n.id for n in notifications])
+                          [nf.id for nf in notifications])
 
     def test_update_view_with_wrong_flag_value(self):
         nf = Notification.objects.get(pk=3)
@@ -522,7 +517,7 @@ class NotificationViewTest(TestCase):
         url = "{}?next=/home/".format(target_page)
         response = self.client.get(url)
 
-        self.assertRedirects(response, "/home/",
+        self.assertRedirects(response, "http://testserver/home/",
                              target_status_code=404, status_code=302)
         nf_new = Notification.objects.get(pk=1)
         self.assertTrue(nf_new.read)
@@ -562,7 +557,7 @@ class NotificationViewTest(TestCase):
         url = "{}?next=/home/".format(target_page)
         response = self.client.get(url)
 
-        self.assertRedirects(response, "/home/",
+        self.assertRedirects(response, "http://testserver/home/",
                              target_status_code=404, status_code=302)
 
         nf_new = Notification.objects.get(pk=3)
